@@ -134,13 +134,13 @@ def open_covfee():
 
 
 def install_npm_packages_if_not_installed():
-    cli_path = app.config['COVFEE_CLI_PATH']
-    npm_package = NPMPackage(cli_path)
+    server_path = app.config['COVFEE_SERVER_PATH']
+    npm_package = NPMPackage(server_path)
     if not npm_package.is_installed():
         npm_package.install()
 
-    client_path = app.config['COVFEE_CLIENT_PATH']
-    npm_package = NPMPackage(client_path)
+    shared_path = app.config['COVFEE_SHARED_PATH']
+    npm_package = NPMPackage(shared_path)
     if not npm_package.is_installed():
         npm_package.install()
 
